@@ -220,10 +220,10 @@ public class MailAccountPOP3Storage implements POP3Storage {
         if (null == src || src.length() == 0) {
             return Long.toString(System.currentTimeMillis());
         }
-        final char[] chars = src.toCharArray();
-        final StringBuilder sb = new StringBuilder(chars.length);
-        for (int i = 0; i < chars.length; i++) {
-            final char c = chars[i];
+        final int length = src.length();
+        final StringBuilder sb = new StringBuilder(length);
+        for (int i = 0; i < length; i++) {
+            final char c = src.charAt(i);
             if (Character.isLetterOrDigit(c)) {
                 sb.append(c);
             }
@@ -525,7 +525,7 @@ public class MailAccountPOP3Storage implements POP3Storage {
                             // Another thread is already in process.
                             return;
                         }
-                    } catch (SQLException e) {
+                    } catch (final SQLException e) {
                         // INSERT failed. Another thread is already in process.
                         return;
                     }
@@ -543,7 +543,7 @@ public class MailAccountPOP3Storage implements POP3Storage {
                         return;
                     }
                 }
-            } catch (SQLException e) {
+            } catch (final SQLException e) {
                 // Concurrency check failed
                 throw POP3ExceptionCode.SQL_ERROR.create(e, e.getMessage());
             } finally {
@@ -885,9 +885,9 @@ public class MailAccountPOP3Storage implements POP3Storage {
         try {
             f = POP3Folder.class.getDeclaredField("message_cache");
             f.setAccessible(true);
-        } catch (SecurityException e) {
+        } catch (final SecurityException e) {
             f = null;
-        } catch (NoSuchFieldException e) {
+        } catch (final NoSuchFieldException e) {
             f = null;
         }
         messageCacheField = f;
